/**
 *  日历组件
 *  @param {object} [option] 
 *     @param [option.showtitle] {string}  日历头部控件? 默认: "true" 
 *     @param [option.preCallback] {function} 上一月回调  默认:null 
 *     @param [option.nextCallback] {function}  下一月回调  默认:null
 *     @param [option.dataRequest] {function}  业务数据改变, 默认:日期2023-08-22
 *     @param [option.onItemClick] {function}  点击日期事件, 默认:null
 * @example
 * 
 *   示例:
 *   
    <component id="calendar" name="pages/components/calendar/index" showtitle="false"></component>
 *
 */

loader.define(async function (requires, exports, module, global) {
  let mid = module.id;
  // 合并接收默认参数
  let props = $.extend(
    true,
    {
      showtitle: true,
      isLunar: false, //
      // 默认日历组件容器
      container: `#${mid} .calendar`,
      // 上一月节点
      pre: `#${mid} .pre`,
      // 下一月节点
      next: `#${mid} .next`,
      // 上一月回调
      preCallback: null,
      // 下一月回调
      nextCallback: null,
      // 业务数据改变
      dataRequest: function (currdate, callback, _this) {
        // 无日程安排
        var data = [
          {
            date: "2023-08-22",
          },
        ];
        callback && callback(data);
      },
      // 点击日期事件
      onItemClick: null,
    },
    module.props
  );

  let onItemClick = props.onItemClick;
  let swipeCallback = props.swipeCallback;

  await loader.import("./libs/swiper.min.css");
  await loader.import("./libs/calendar_base.css");
  await loader.import("./css/showcase.css");

  await loader.importSync("./libs/swiper.min.js");
  await loader.importSync("./libs/mustache.min.js");
  await loader.importSync("./libs/calendar_base.js");

  // 初始化数据行为存储
  var bs = bui.store({
    el: `#${module.id}`,
    scope: "calendar",
    data: {
      showtitle: props.showtitle,
    },
    methods: {
      init(opt) {
        opt.onItemClick = function (item) {
          // 设置标题
          document.querySelector(`#${mid} .mid span`).innerText = item.date;
          onItemClick && onItemClick.call(this, item); //传进来的onItemClick事件
        };
        opt.swipeCallback = function (item) {
          document.querySelector(`#${mid} .mid span`).innerText = item.date;
          swipeCallback && swipeCallback.call(this, item);
        };

        var ui = new Calendar(opt);
        return ui;
      },
    },
    watch: {},
    computed: {},

    mounted: function () {
      // 数据解析后执行
      this.calendar = this.init(props);
    },
  });

  return bs;
});
